A sample Python project
=======================

Lel is a lisp like programming language. It is not meant for practical purposes, but more as a tool to learn how to write a programming language.

This project comes with a Lel interpreter for running Lel programs, and a REPL for executing Lel expressions in real time.

----
Acknowledgement:

The language syntax and the first version in javascript node.js was written by Frank Stokes.

Please check his repository for the details: https://github.com/francisrstokes/Lisp-esque-language
